# English language data

from .base import DocData, Hymn

# noinspection SpellCheckingInspection
doc_data = DocData(
    [
        Hymn(
            1001,
            "6e/4e/6e4ecd14ebb511ee863aeeeeac1eaa7887580260/come_thou_fount_of_every_blessing.pdf",
            False,
        ),
        Hymn(
            1002,
            "70/a7/70a7ff54ebb511eeb4d5eeeeac1ea6754c802f3d/when_the_savior_comes_again.pdf",
        ),
        Hymn(
            1003,
            "6f/d3/6fd34a32ebb511eea3b1eeeeac1e2cdd0ffc6784/it_is_well_with_my_soul.pdf",
        ),
        Hymn(
            1004,
            "6f/cb/6fcb5af5ebb511ee903eeeeeac1e7de67f84090e/i_will_walk_with_jesus.pdf",
        ),
        Hymn(
            1005,
            "6f/00/6f001bb4ebb511eea424eeeeac1e211e768ee551/his_eye_is_on_the_sparrow.pdf",
        ),
        Hymn(
            1006,
            "70/39/703937f5ebb511ee888feeeeac1e36706b2e5f48/think_a_sacred_song.pdf",
        ),
        Hymn(
            1007,
            "6d/f3/6df3dbd5ebb511eea9a7eeeeac1eca3ca4ff6c01/as_bread_is_broken.pdf",
            False,
        ),
        Hymn(
            1008,
            "6e/06/6e062b55ebb511eeb343eeeeac1ef072e68df91f/bread_of_life_living_water.pdf",
            False,
            True,
        ),
        Hymn(1009, "6e/79/6e795f87ebb511eebd27eeeeac1ef760eeedab62/gethsemane.pdf"),
        Hymn(
            1010,
            "oh/5v/oh5v0ejqfx70w7i6aq4bvhl1e9plpoyld9mk331x/amazing_grace.pdf",
            False,
            True,
        ),
        Hymn(
            1011,
            "6f/37/6f37cd82ebb511eebbd6eeeeac1e993e0630c9ee/holding_hands_around_the_world.pdf",
        ),
        Hymn(
            1012,
            "kn/rv/knrvba9apal6ivg0fo1u332xpvv9jhvdl4lg7yik/anytime_anywhere.pdf",
            False,
            True,
        ),
        Hymn(
            1013,
            "md/4f/md4f9a3ntjzegeiqu52w4x3g2yt733eydjv63ep5/gods_gracious_love.pdf",
        ),
        Hymn(
            1014,
            "8d/vf/8dvfxy75bz6w764yerum41314ynuwg7dqn6wkxa0/my_shepherd_will_supply_my_need.pdf",
        ),
        Hymn(
            1015,
            "nk/kl/nkklkoxo47tg4g8ev5sifeha39r6eipa55evuupy/oh_the_deep_deep_love_of_jesus.pdf",
            False,
            True,
        ),
        Hymn(
            1016,
            "ou/qn/ouqn58wbc3ieqcnvdi38gbym6co5tejigxinfaw2/behold_the_wounds_in_jesus_hands.pdf",
        ),
        Hymn(
            1017,
            "z5/bf/z5bf1f2266jq08sp0l13nbbijbwl6kad9ze836sd/this_is_the_christ.pdf",
        ),
        Hymn(
            1018, "ib/hy/ibhyon46m2ibnt1synq1yaeciqqft4ef1h17xb44/come_lord_jesus.pdf"
        ),
        Hymn(
            1019,
            "jb/ni/jbniwxerq9gpvsubg55yk2ym1mczb3jt0xzohzry/to_love_like_thee.pdf",
            False,
            True,
        ),
        Hymn(
            1020,
            "6a/5o/6a5oag5khmdh2ssecgqgqrd3vnwsta9jqo1z0z9n/softly_and_tenderly_jesus_is_calling.pdf",
        ),
        Hymn(
            1021,
            "fn/bv/fnbvm8jbmrn47ug6qbu0eu6dwunucay4ljkqk1e2/i_know_that_my_savior_loves_me.pdf",
        ),
        Hymn(
            1022,
            "3j/s4/3js483x1nxmpouv32y3awvi77x108p44c6a9907s/faith_in_every_footstep.pdf",
        ),
        Hymn(
            1023,
            "79/ta/79tasqd6cffgga673rdaffgqe050d5dexf8z101i/standing_on_the_promises.pdf",
        ),
        Hymn(
            1024,
            "rz/hd/rzhd1yskdtpndjchivbyr2b9mf7gmlerlik6dgtu/i_have_faith_in_the_lord_jesus_christ.pdf",
        ),
        Hymn(
            1025,
            "ii/ox/iioxw8p3civdmchb71pw21v5zu5cozmyy7lx6ueq/take_my_heart_and_let_it_be_consecrated.pdf",
        ),
        Hymn(
            1026,
            "fq/wd/fqwdqbzjmdbivv679bzezgr47h28xb8qz0yg32l0/holy_places.pdf",
            False,
        ),
        Hymn(1027, "eq/uh/equhtieoxfdjgdldggamp4nw74jz8ub6pvrpbb3q/welcome_home.pdf"),
        Hymn(
            1028,
            "c9/6u/c96ux9no50moe9a1s57oy4gm1kcr2dk1cu0drci2/this_little_light_of_mine.pdf",
        ),
        Hymn(
            1029,
            "fl/gz/flgzaf0vovtww2p97xbsqsmmxtlyuzamowaz980b/i_cant_count_them_all.pdf",
            False,
        ),
        Hymn(
            1030,
            "95/6c/956cqf7l7rwugkycu2sp6s47vcxd0l8sil0bqb7d/close_as_a_quiet_prayer.pdf",
        ),
        Hymn(
            1031,
            "o8/wi/o8wigqygh5dll0mxq6qvegfy9gbcu8815uxpbic1/come_hear_the_word_the_lord_has_spoken.pdf",
        ),
        Hymn(
            1032,
            "ks/iq/ksiqaqmbw5d73vtpbvjl9i1hwp1991hezj80z10t/look_unto_christ.pdf",
            False,
        ),
        Hymn(
            1033,
            "1j/kg/1jkgot13zdk5ij9ir1gvw785bvi5jkafom5knwov/oh_how_great_is_our_joy.pdf",
        ),
        Hymn(
            1034, "fk/hv/fkhv4f39s3sgbrkzjj891iak4st1fagrycdge7m9/im_a_pioneer_too.pdf"
        ),
        Hymn(
            1035,
            "87/af/87aferimm4bh9h1asmajpvlnx902w98ehjpfv577/as_i_keep_the_sabbath_day.pdf",
            False,
        ),
        Hymn(
            1036,
            "vj/vq/vjvqnfv5f0180jmyzm8oewrmiu61hl2vykalwm56/read_the_book_of_mormon_and_pray.pdf",
        ),
        Hymn(
            1037,
            "af/ny/afny05n5s6xkznyrhv4vqdjnh76qs1576vjahmwo/im_gonna_live_so_god_can_use_me.pdf",
        ),
        Hymn(
            1038,
            "wg/rf/wgrfga1tcvxx56agz3lh62apy67aofyu6yhhgf2b/the_lords_my_shepherd.pdf",
            False,
        ),
        Hymn(1039, "l8/aa/l8aa8iq55nwm4ppvfm3qcr34oi81as8jwngih6kp/because.pdf"),
        Hymn(
            1040,
            "r6/rl/r6rli8pz3gawtj2f9bf9144ubs1zjlt4j6bxbcwl/his_voice_as_the_sound.pdf",
        ),
        Hymn(
            1041,
            "cj/oh/cjohf082cbp6pbodqau3zm9i9gmi4i3yk8hzdtsy/o_lord_who_gave_thy_life_for_me.pdf",
        ),
        Hymn(
            1042,
            "he/86/he86n6sqvar4ysrork5belj8fh33pbo914om83a9/thou_gracious_god_whose_mercy_lends.pdf",
            False,
        ),
        Hymn(
            1043, "mr/ii/mrii3sw2leivfi17lixh2v43i9pk1q73whpo9szo/help_us_remember.pdf"
        ),
        Hymn(
            1044,
            "28/35/28358y5wthp49fr4l0y3igtij3fnm2m0crxitxjd/how_did_the_savior_minister.pdf",
            False,
        ),
        Hymn(
            1045, "wg/82/wg82l7rydm9uzmnhw73gb77kdc6rny669trfwd6h/jesus_is_the_way.pdf"
        ),
        Hymn(
            1046,
            "ai/ln/ailn1tipdgc7out8odgcag8447od5u017ug3y7ou/can_you_count_the_stars_in_heaven.pdf",
        ),
        Hymn(
            1047,
            "x5/pa/x5pa1fa3sc3rkd6h679gaoprntum2j3ixl56ukpy/he_cares_for_me.pdf",
            False,
        ),
        Hymn(
            1048,
            "k4/hg/k4hg4muphm8mhqj8sb9eypt6yxv0edbb7w0upnlx/our_prayer_to_thee.pdf",
        ),
        Hymn(
            1049,
            "em/a0/ema0yxz439lqcgqevi4hy75cn9p55vxq9rb8wt4n/joseph_prayed_in_faith.pdf",
        ),
        Hymn(1050, "9x/3j/9x3jwrluybs3w8irtxo9e4mxdz39tqayhm7cmbm5/stand_by_me.pdf"),
        Hymn(
            1051,
            "9v/mm/9vmmfbdua2bpgmhufmx51o29itb8soq7bwowhf73/this_day_is_a_good_day_lord.pdf",
            False,
        ),
        Hymn(
            1201,
            "6e/9f/6e9fac3debb511eea036eeeeac1ec84f90cdba38/hail_the_day_that_sees_him_rise.pdf",
            False,
            True,
        ),
        Hymn(
            1202,
            "6e/d8/6ed86f77ebb511eeb141eeeeac1eae03688eebd1/he_is_born_the_divine_christ_child.pdf",
            False,
            True,
        ),
        Hymn(
            1203,
            "70/73/707381d2ebb511eeb518eeeeac1e3b993d94e337/what_child_is_this.pdf",
        ),
        Hymn(1204, "6f/fb/6ffbe0d8ebb511eeb958eeeeac1e769f17b3574f/star_bright.pdf"),
        Hymn(
            1205,
            "8z/nn/8znn69tb6fr1h2ctl0nkswt7ma8lc80jlklepyd6/let_easter_anthems_ring.pdf",
            False,
            True,
        ),
        Hymn(1206, "35/d0/35d0uc1i13madxx6wzlecpu3347lv09uebqrs75o/were_you_there.pdf"),
        Hymn(
            1207, "2z/gf/2zgfzovjzxpf440zhrjzixmxrmvih0r8b9h7sdnf/still_still_still.pdf"
        ),
        Hymn(
            1208,
            "cz/23/cz23g18i6a1kufdab9szptg26rq3j0kxhy2nfiod/go_tell_it_on_the_mountain.pdf",
            False,
        ),
        Hymn(
            1209,
            "jr/vl/jrvlt8nplnk8dejytlbilk8ej156pw22nfs7tdrm/little_baby_in_a_manger.pdf",
        ),
    ]
)
