# Español (Spanish) language data

from .base import DocData, Hymn

# noinspection SpellCheckingInspection
doc_data = DocData(
    [
        Hymn(
            1001,
            "c2/84/c284c254073b11efbfd2eeeeac1e0cc7c94404a1/come_thou_fount_of_every_blessing.pdf",
            False,
        ),
        Hymn(
            1002,
            "6b/9b/6b9b7f4b0ca311ef8fc9eeeeac1e0de2bbf1578f/when_the_savior_comes_again.pdf",
        ),
        Hymn(
            1003,
            "61/2d/612daab80ca311ef9be7eeeeac1ec3fd60ec888c/it_is_well_with_my_soul.pdf",
        ),
        Hymn(
            1004,
            "60/96/609625ac0ca311efa648eeeeac1e2f5955fd268c/i_will_walk_with_jesus.pdf",
        ),
        Hymn(
            1005,
            "5e/a3/5ea3565f0ca311efb941eeeeac1ef7cfdf0191ba/his_eye_is_on_the_sparrow.pdf",
        ),
        Hymn(
            1006,
            "69/dc/69dcdf5b0ca311ef8e16eeeeac1ea134e1752487/think_a_sacred_song.pdf",
        ),
        Hymn(
            1007,
            "5a/54/5a546e9b0ca311ef80a4eeeeac1e1a8976dcfe6c/as_bread_is_broken.pdf",
            False,
        ),
        Hymn(
            1008,
            "5b/4c/5b4c8a3f0ca311efaf3ceeeeac1e008b2ff6cee6/bread_of_life_living_water.pdf",
            False,
            True,
        ),
        Hymn(1009, "5c/2a/5c2ab53a0ca311ef8fc9eeeeac1e0de2710d4e06/gethsemane.pdf"),
        Hymn(
            1010,
            "rj/md/rjmdkfwcvyj40z9x5mptv3rlp3mjq0r3f2ajvz3o/amazing_grace.pdf",
            False,
            True,
        ),
        Hymn(
            1011,
            "5f/cd/5fcd576f0ca311efb82eeeeeac1e03e733245bc0/holding_hands_around_the_world.pdf",
        ),
        Hymn(
            1012,
            "ie/jk/iejkdwj6ogfhn6gcok301zck7s0vgbe1ch5ltiqa/anytime_anywhere.pdf",
            False,
            True,
        ),
        Hymn(
            1013,
            "zu/nl/zunlwr8mxkcfs1kgwcupi3y2kyhds082vokow4e3/gods_gracious_love.pdf",
        ),
        Hymn(
            1014,
            "w1/z8/w1z84shlyiaxdiv3dz98f2otmp1h8g11qxiaooxl/my_shepherd_will_supply_my_need.pdf",
        ),
        Hymn(
            1015,
            "27/fo/27fo18n3uiobq291iegxy2j3j96rqc73g5mmavfb/oh_the_deep_deep_love_of_jesus.pdf",
            False,
            True,
        ),
        Hymn(
            1016,
            "1d/cb/1dcbgah3w40qzk0yj2mw2mqbi9mxjohrzo0t9z1r/behold_the_wounds_in_jesus_hands.pdf",
        ),
        Hymn(
            1017,
            "k1/r6/k1r6w3qrec4frhpd9uv7xqst2ds3qqihw2k2ebwe/this_is_the_christ.pdf",
        ),
        Hymn(
            1018, "af/6a/af6acu0yilofg8ir3okj65ok0dzgj4pztjbz9rvt/come_lord_jesus.pdf"
        ),
        Hymn(
            1019,
            "v9/3m/v93moe9wq88u72jcegrml14tiay33yhelzi1u14c/to_love_like_thee.pdf",
            False,
            True,
        ),
        Hymn(
            1020,
            "dd/lr/ddlron658e7ddvysueq896d705ocaiegkyctm79l/softly_and_tenderly_jesus_is_calling.pdf",
        ),
        Hymn(
            1021,
            "qq/z5/qqz5xu4ml313y9y5zc9ddrtjh2v0dy4p0a7oetcm/i_know_that_my_savior_loves_me.pdf",
        ),
        Hymn(
            1022,
            "nf/y0/nfy0b6o8a8nict43hjiw8wouzhygzq1j8n0r0xb9/faith_in_every_footstep.pdf",
        ),
        Hymn(
            1023,
            "od/gb/odgbnqo5s3xtpj1gfuj4o0cexj494dznmynhzroz/standing_on_the_promises.pdf",
        ),
        Hymn(
            1024,
            "7a/5j/7a5josf3w4uqvia5kid7d25e7qbi41h48bg2va4b/i_have_faith_in_the_lord_jesus_christ.pdf",
        ),
        Hymn(
            1025,
            "m4/hx/m4hxp2k110signsnn2og7nuvlzitpqsf56oujb8k/take_my_heart_and_let_it_be_consecrated.pdf",
        ),
        Hymn(
            1026,
            "m4/t2/m4t2kz3s1cm4qirncmy6c5u99v27hm6sysib5y5g/holy_places.pdf",
            False,
        ),
        Hymn(1027, "2f/03/2f0382g3csuryqk8ed6fyc7eyav2m14hig9475t1/welcome_home.pdf"),
        Hymn(
            1028,
            "5y/hb/5yhb3bx04vzoib9knwtkwrqlkgutxvphb6e6wo4c/this_little_light_of_mine.pdf",
        ),
        Hymn(
            1029,
            "td/3c/td3crppjmqvown4gld4jt294zy5u7sg01i79su78/i_cant_count_them_all.pdf",
            False,
        ),
        Hymn(
            1030,
            "1s/dw/1sdw6aog5dz1o7bdcsd8ymtd5gfldd433ha552e3/close_as_a_quiet_prayer.pdf",
        ),
        Hymn(
            1031,
            "dd/hx/ddhx8cggoprf726m2fro8xfj7l97fzqsyv9df4w8/come_hear_the_word_the_lord_has_spoken.pdf",
        ),
        Hymn(
            1032,
            "xr/5w/xr5wt8srqghwh8fdipaqw9fogxykygfk36aj12fx/look_unto_christ.pdf",
            False,
        ),
        Hymn(
            1033,
            "9z/54/9z54zv645djbm8uc88fz436fztc9unecxlq5f01u/oh_how_great_is_our_joy.pdf",
        ),
        Hymn(
            1034, "bu/6s/bu6spilnlhr3srp430n3pwzjene7zomnqhaveenw/im_a_pioneer_too.pdf"
        ),
        Hymn(
            1035,
            "2z/yc/2zyc0ve956dpyokbyo9ft460oynapd2ft1po395n/as_i_keep_the_sabbath_day.pdf",
            False,
        ),
        Hymn(
            1036,
            "5g/0c/5g0c09k3vi05akrwfcp9ekeficqo44pisoktzrf1/read_the_book_of_mormon_and_pray.pdf",
        ),
        Hymn(
            1037,
            "gb/92/gb92hl3y9zfgbw5m28vofy9ht2jtdsz3qrd7zv09/im_gonna_live_so_god_can_use_me.pdf",
        ),
        Hymn(
            1038,
            "wg/68/wg68cd6nirfbhchkq1j0tjb49kjg96s3k9vdrwa8/the_lords_my_shepherd.pdf",
            False,
        ),
        Hymn(1039, "aq/i0/aqi0oy1939ymjl1skxy7zd0orf9x9chhe8dwlpb0/because.pdf"),
        Hymn(
            1040,
            "kk/k8/kkk89410m2osdpeoqpby7px2ra8lovnzj1qcy41o/his_voice_as_the_sound.pdf",
        ),
        Hymn(
            1041,
            "o1/sb/o1sb39bgi537vs0d895qnvncobt7pxwp5nmfl5yc/o_lord_who_gave_thy_life_for_me.pdf",
        ),
        Hymn(
            1042,
            "tc/ig/tcigk91tyuw3n9t9f0q4wvswv94gqzflzuelgnvk/thou_gracious_god_whose_mercy_lends.pdf",
            False,
        ),
        Hymn(
            1043, "1q/9j/1q9jvvf7vy3y7j9lxmxc5hqd5qi3xnb79wf165oy/help_us_remember.pdf"
        ),
        Hymn(
            1044,
            "0g/c9/0gc9gsdp2sb43jg4egv08gqsi12apkzelm4a5stg/how_did_the_savior_minister.pdf",
            False,
        ),
        Hymn(
            1045, "2g/i4/2gi4kjd1550nefbh005ehe532f4km51x9wxi2epi/jesus_is_the_way.pdf"
        ),
        Hymn(
            1046,
            "4o/bt/4obtwpkv22ubjrybftzjln97u097js7882sipix6/can_you_count_the_stars_in_heaven.pdf",
        ),
        Hymn(
            1047,
            "a1/e4/a1e4zgu650frq8k370x1sqtr68dplxagur7scuqc/he_cares_for_me.pdf",
            False,
        ),
        Hymn(
            1048,
            "s2/3w/s23w461r583stts2vvzd2f678rxwubsg1y1g4pp6/our_prayer_to_thee.pdf",
        ),
        Hymn(
            1049,
            "bf/xd/bfxdsj9nj5say3zkdhsx7f08xaym4jz0ec68xi50/joseph_prayed_in_faith.pdf",
        ),
        Hymn(1050, "nt/xm/ntxmrkk4uu3x4zf3xmgqu5op6xuh81opgg6w9rrr/stand_by_me.pdf"),
        Hymn(
            1051,
            "r5/h4/r5h4wk2xzubdzest97lsdtvuwr4jxxghlgpggws9/this_day_is_a_good_day_lord.pdf",
            False,
        ),
        Hymn(
            1201,
            "5d/1e/5d1e15ee0ca311efb82eeeeeac1e03e79b85b9b2/hail_the_day_that_sees_him_rise.pdf",
            False,
            True,
        ),
        Hymn(
            1202,
            "5d/ba/5dbacb230ca311ef823ceeeeac1ea7cf84767a94/he_is_born_the_divine_christ_child.pdf",
            False,
            True,
        ),
        Hymn(
            1203,
            "6a/de/6ade49c60ca311ef89fbeeeeac1e28fb7942f974/what_child_is_this.pdf",
        ),
        Hymn(1204, "80/02/8002fa220e8611efb3baeeeeac1e55fa95392dc5/star_bright.pdf"),
        Hymn(
            1205,
            "ac/au/acauj22rj8p1prejn4zq4w5v00x0ygkk9mzk47rx/let_easter_anthems_ring.pdf",
            False,
            True,
        ),
        Hymn(1206, "v3/gd/v3gd4rag00g44u16ik7v8noshtwt94gq6uc2law8/were_you_there.pdf"),
        Hymn(
            1207, "a2/yr/a2yr0k9yk46j787x26u6wlz5kaxr04u05idcyvwh/still_still_still.pdf"
        ),
        Hymn(
            1208,
            "g0/7w/g07w5zsl9a6ir1nmnropyomzmmplnoifzs63867e/go_tell_it_on_the_mountain.pdf",
            False,
        ),
        Hymn(
            1209,
            "2o/81/2o8195dbo3l5wozi18sb07mvekcmkpcxph0estm0/little_baby_in_a_manger.pdf",
        ),
    ],
    title="Himnos \x97 Para el hogar y la Iglesia",
    t_font_size=dict(a4=33, letter=33),
    hymn_link_text="Escanee este código para acceder los himnos digitalmente",
    rev_text="Revisión",
    lang="spa",
)
