# Português (Portuguese) language data

from .base import DocData, Hymn

# noinspection SpellCheckingInspection
doc_data = DocData(
    [
        Hymn(
            1001,
            "0e/a8/0ea81285073d11efae2feeeeac1ed46377082433/come_thou_fount_of_every_blessing.pdf",
            False,
        ),
        Hymn(
            1002,
            "59/cb/59cb4e5e0cb311ef8f10eeeeac1ecb45755560c4/when_the_savior_comes_again.pdf",
        ),
        Hymn(
            1003,
            "4b/61/4b6145ea0cb311ef9f33eeeeac1efd649a526215/it_is_well_with_my_soul.pdf",
        ),
        Hymn(
            1004,
            "4a/c5/4ac505df0cb311ef88feeeeeac1e90d53b8b981f/i_will_walk_with_jesus.pdf",
        ),
        Hymn(
            1005,
            "48/01/4801ee500cb311efac02eeeeac1e2d1ab1d37dfb/his_eye_is_on_the_sparrow.pdf",
        ),
        Hymn(
            1006,
            "57/6e/576e247b0cb311ef9f33eeeeac1efd64e11347d2/think_a_sacred_song.pdf",
        ),
        Hymn(
            1007,
            "42/d7/42d79aad0cb311ef9be7eeeeac1ec3fd988b6e0b/as_bread_is_broken.pdf",
            False,
        ),
        Hymn(
            1008,
            "43/c7/43c778ea0cb311ef8f34eeeeac1ec1d405de0b25/bread_of_life_living_water.pdf",
            False,
            True,
        ),
        Hymn(1009, "44/95/449550400cb311ef81e1eeeeac1e92868734b100/gethsemane.pdf"),
        Hymn(
            1010,
            "ab/1v/ab1v5rnkdvaxzy1w0uo52lmdet22ldz674vdv1vz/amazing_grace.pdf",
            False,
            True,
        ),
        Hymn(
            1011,
            "4a/14/4a14a1ae0cb311ef9be7eeeeac1ec3fda2cf4ae2/holding_hands_around_the_world.pdf",
        ),
        Hymn(
            1012,
            "rq/qe/rqqe9n9jrk2y1d9fsruysik42jc4yqss0c9q2dvx/anytime_anywhere.pdf",
            False,
            True,
        ),
        Hymn(
            1013,
            "1o/nb/1onbjq054l153fjyrjqyv4wtedufo8fer4jhcfjx/gods_gracious_love.pdf",
        ),
        Hymn(
            1014,
            "d8/3e/d83e581j0kf5j02w8sz57hj2xudi01ety1j9weo4/my_shepherd_will_supply_my_need.pdf",
        ),
        Hymn(
            1015,
            "9l/lh/9llhcchcn6zsovzsfzy33m7wt4ss037n2lzynier/oh_the_deep_deep_love_of_jesus.pdf",
            False,
            True,
        ),
        Hymn(
            1016,
            "ls/xu/lsxudhhk6p5wfb1ofau1g6qoqss767nhscp0r0vt/behold_the_wounds_in_jesus_hands.pdf",
        ),
        Hymn(
            1017,
            "tx/ts/txtsjdh2lf3rz110np604r2b6wza73nyrdbgy4u2/this_is_the_christ.pdf",
        ),
        Hymn(
            1018, "29/ht/29htr2piqnd2gn5bdjovd30y5gwhs8pemkz7cbjb/come_lord_jesus.pdf"
        ),
        Hymn(
            1019,
            "5r/6h/5r6hc4i2m83hs7lomd7gb5cpbn5bjkvsq3qxu76p/to_love_like_thee.pdf",
            False,
            True,
        ),
        Hymn(
            1020,
            "vb/dk/vbdk330ilbuhc7179mzab5llhkuentinm1y5qryt/softly_and_tenderly_jesus_is_calling.pdf",
        ),
        Hymn(
            1021,
            "ec/f8/ecf8sg80uyj49r5d846lmcm8dyf9bqqhu3y84sd4/i_know_that_my_savior_loves_me.pdf",
        ),
        Hymn(
            1022,
            "2z/4z/2z4ztwzyh4782ouq2v9d5dhi16gagp2czt0r7fas/faith_in_every_footstep.pdf",
        ),
        Hymn(
            1023,
            "sv/mn/svmnn3qv1rhgymfbc8sj1pmrv86lfngwurgrmyfo/standing_on_the_promises.pdf",
        ),
        Hymn(
            1024,
            "xr/i1/xri1fqdf6xw1qx3povhuwcwrkr9fx8prpl338oux/i_have_faith_in_the_lord_jesus_christ.pdf",
        ),
        Hymn(
            1025,
            "vr/b0/vrb0rvx60ru6lrtyu6eslhah7hfjj1o3qks2xus1/take_my_heart_and_let_it_be_consecrated.pdf",
        ),
        Hymn(
            1026,
            "3n/1y/3n1yi7fmpimb199y2k3o3vnxdaxw6q4xd9t3g09p/holy_places.pdf",
            False,
        ),
        Hymn(1027, "lg/v1/lgv153h44t36jrvtn6aewq5ti5nzo4apdv0nm2k8/welcome_home.pdf"),
        Hymn(
            1028,
            "3d/4v/3d4v9nqdsc7es9aigcx0uu4cbam4ekiriljnebk1/this_little_light_of_mine.pdf",
        ),
        Hymn(
            1029,
            "fg/5f/fg5ffnv5hcbt9ed2a536ufs2rebkl49xr6xx55og/i_cant_count_them_all.pdf",
            False,
        ),
        Hymn(
            1030,
            "7n/lx/7nlxw0awrwm48t3rm9zy44i92h6ve50ovhboyk56/close_as_a_quiet_prayer.pdf",
        ),
        Hymn(
            1031,
            "lz/0h/lz0hcxwj4zmix2r5nl17trs1knzrfkqcosi31cw4/come_hear_the_word_the_lord_has_spoken.pdf",
        ),
        Hymn(
            1032,
            "ve/kq/vekq8lhs33l7aj83wuugsy0x5n2snn7l3u5c8wp8/look_unto_christ.pdf",
            False,
        ),
        Hymn(
            1033,
            "vi/kv/vikvr874exjzrx3iaxvm0ba0m606hzjc7z8wdf4n/oh_how_great_is_our_joy.pdf",
        ),
        Hymn(
            1034, "69/n3/69n3vkkfo72ydsap47zuz03kfbj3nywklo6lxlet/im_a_pioneer_too.pdf"
        ),
        Hymn(
            1035,
            "9b/2v/9b2vc5ztzcowrt40ph214h2kz72xbxvgmc8swsni/as_i_keep_the_sabbath_day.pdf",
            False,
        ),
        Hymn(
            1036,
            "ln/pl/lnplx328sxrw2d4e2veap39i8wvjvstl0d47z4ja/read_the_book_of_mormon_and_pray.pdf",
        ),
        Hymn(
            1037,
            "rk/cw/rkcwxikjn02egjq6ji50xs8wv31dijkxw2myblk7/im_gonna_live_so_god_can_use_me.pdf",
        ),
        Hymn(
            1038,
            "vf/p1/vfp1t5yawhhqknr3ewykddhvzn44q3fbz96bdpxo/the_lords_my_shepherd.pdf",
            False,
        ),
        Hymn(1039, "18/xf/18xf2nv5nl53umpxu6mxtfuhob4pyxgdbw5n48r9/because.pdf"),
        Hymn(
            1040,
            "q5/ft/q5ft2in03jylm6szyeuhksi7irnbs77bq84bkz0j/his_voice_as_the_sound.pdf",
        ),
        Hymn(
            1041,
            "8h/7j/8h7jwm8q2be68hfhxbay979cheh8hps1wcapkacc/o_lord_who_gave_thy_life_for_me.pdf",
        ),
        Hymn(
            1042,
            "3j/ab/3jabs0r5ucsyxgso7xfb759u3oby4aigjsda2mmw/thou_gracious_god_whose_mercy_lends.pdf",
            False,
        ),
        Hymn(
            1043, "sh/j3/shj3a53mday5zm0gi6dfs5i67l7w880h3k04ef8c/help_us_remember.pdf"
        ),
        Hymn(
            1044,
            "hj/9l/hj9lblkef6y57t3pmh0s6an56zfaswc9zrgm0td5/how_did_the_savior_minister.pdf",
            False,
        ),
        Hymn(
            1045, "tq/b3/tqb36xjdy41o2w84qevdxyzfun55s6wvhasokkyj/jesus_is_the_way.pdf"
        ),
        Hymn(
            1046,
            "re/lf/relf01rd60vhkf81ut71y2e96ubf9eooy3v06kbc/can_you_count_the_stars_in_heaven.pdf",
        ),
        Hymn(
            1047,
            "5g/hs/5ghs0w7gdcuevi71rqyu82tnjhyuv4rhyltx8eej/he_cares_for_me.pdf",
            False,
        ),
        Hymn(
            1048,
            "2m/yu/2myu2fx50bb92yd3j2ojifjeicp1rh8j6sds2gp3/our_prayer_to_thee.pdf",
        ),
        Hymn(
            1049,
            "lz/41/lz41bgol3efryinliy07s0mfhvu1npdizqfwkj1c/joseph_prayed_in_faith.pdf",
        ),
        Hymn(1050, "6s/uw/6suwc45qggeh6wmsbg4bqe4548idlqk4a3hu721b/stand_by_me.pdf"),
        Hymn(
            1051,
            "3x/w8/3xw87dpu6e60tcj805pi2ld5vvv4825wncpgg0hu/this_day_is_a_good_day_lord.pdf",
            False,
        ),
        Hymn(
            1201,
            "45/87/458703350cb311efaf07eeeeac1e99beb8fedf6e/hail_the_day_that_sees_him_rise.pdf",
            False,
            True,
        ),
        Hymn(
            1202,
            "46/a4/46a45a200cb311ef8a83eeeeac1e9d163846f078/he_is_born_the_divine_christ_child.pdf",
            False,
            True,
        ),
        Hymn(
            1203,
            "58/9f/589fedbe0cb311efb8f9eeeeac1e6f4bd4ca924c/what_child_is_this.pdf",
        ),
        Hymn(1204, "56/47/564730a20cb311efa648eeeeac1e2f595efab152/star_bright.pdf"),
        Hymn(
            1205,
            "68/82/6882hfxekci93yiwfarg91fgkg1tgzukh2x0kwjx/let_easter_anthems_ring.pdf",
            False,
            True,
        ),
        Hymn(1206, "s9/ru/s9ru99vxqws6c6nxrvueojhgstv6jnzekdolfe50/were_you_there.pdf"),
        Hymn(
            1207, "ue/ih/ueihr5b8g7df8p38iju29vs5qky39wsnc0dvigeo/still_still_still.pdf"
        ),
        Hymn(
            1208,
            "rk/4d/rk4drariukhnsrxdkhlnwj93cx31ym4kod589qoj/go_tell_it_on_the_mountain.pdf",
            False,
        ),
        Hymn(
            1209,
            "bt/86/bt86shn0r4z6pe9d4a8xlyekxp2iiiz03h4u4hrg/little_baby_in_a_manger.pdf",
        ),
    ],
    title="Hinos \x97 Para o Lar e para a Igreja",
    t_font_size=dict(a4=34, letter=35),
    hymn_link_text="Digitalize este código para acessar esses hinos digitalmente",
    rev_text="Revisão",
    lang="por",
)
